library digital_3g_common;

import 'package:flutter/material.dart';

const Color darkGrey = Color(0xFF555555);

const Color grey = Color(0xFFC7C9C7);

const Color magenta = Color(0xFFD73367);

const Color primary = Color(0xFF00205B);

const Color secondary = Color(0xFF18B0E2);

final textTheme = TextTheme(
  bodyText1: const TextStyle(fontFamily: 'FFMeta', package: 'digital_3g_common'),
  bodyText2: const TextStyle(fontFamily: 'FFMeta', fontSize: 20.0, package: 'digital_3g_common'),
  subtitle1: const TextStyle(fontFamily: 'FFMeta', fontSize: 18.0, package: 'digital_3g_common'),
  subtitle2: TextStyle(fontFamily: 'FFMeta', color: Colors.grey[900], package: 'digital_3g_common'),
  headline4: const TextStyle(
    fontWeight: FontWeight.w900,
    fontFamily: 'FFMeta',
    package: 'digital_3g_common',
    fontSize: 32.0,
    color: Colors.black,
  ),
  headline5: const TextStyle(
    fontWeight: FontWeight.w700,
    fontFamily: 'FFMeta',
    fontSize: 26.0,
    package: 'digital_3g_common',
  ),
  headline6: const TextStyle(
    fontWeight: FontWeight.w700,
    fontFamily: 'FFMeta',
    fontSize: 20.0,
    package: 'digital_3g_common',
  ),
);

final themeData = ThemeData(
  primaryColor: primary,
  colorScheme: ThemeData.light().colorScheme.copyWith(primary: primary, secondary: secondary),
  scaffoldBackgroundColor: grey,
  fontFamily: 'FFMeta',
  textTheme: textTheme,
  iconTheme: const IconThemeData(color: darkGrey),
  appBarTheme: AppBarTheme(
    titleTextStyle: textTheme.headline6,
    toolbarTextStyle: textTheme.headline6,
    backgroundColor: primary,
    centerTitle: true,
  ),
  cardTheme: CardTheme(
    shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8.0)),
  ),
  elevatedButtonTheme: ElevatedButtonThemeData(
    style: ButtonStyle(
      foregroundColor: MaterialStateProperty.resolveWith<Color>((_) => Colors.white),
      backgroundColor: MaterialStateProperty.resolveWith<Color>(
          (state) => state.contains(MaterialState.disabled) ? primary.withAlpha(128) : primary),
      splashFactory: InkRipple.splashFactory,
      overlayColor: MaterialStateProperty.resolveWith<Color>((_) => Colors.white24),
      textStyle: MaterialStateProperty.resolveWith<TextStyle>((_) => const TextStyle(
            fontWeight: FontWeight.w700,
            fontFamily: 'FFMeta',
            package: 'digital_3g_common',
          )),
    ),
  ),
  textButtonTheme: TextButtonThemeData(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.resolveWith<Color>(
          (state) => state.contains(MaterialState.disabled) ? primary.withAlpha(128) : primary),
      foregroundColor: MaterialStateProperty.resolveWith<Color>((_) => Colors.white),
      splashFactory: InkRipple.splashFactory,
      overlayColor: MaterialStateProperty.resolveWith<Color>((_) => Colors.white24),
      textStyle: MaterialStateProperty.resolveWith<TextStyle>((_) => const TextStyle(
            fontWeight: FontWeight.w700,
            fontFamily: 'FFMeta',
            package: 'digital_3g_common',
          )),
    ),
  ),
  textSelectionTheme: const TextSelectionThemeData(
    cursorColor: secondary,
  ),
  inputDecorationTheme: const InputDecorationTheme(
    focusedBorder: UnderlineInputBorder(
      borderSide: BorderSide(color: secondary, width: 2.0),
    ),
  ),
  dialogTheme: const DialogTheme(
    shape: RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(8.0))),
    titleTextStyle: TextStyle(
      fontWeight: FontWeight.w700,
      fontFamily: 'FFMeta',
      package: 'digital_3g_common',
      color: Colors.black,
      fontSize: 20.0,
    ),
  ),
  checkboxTheme: CheckboxThemeData(
    fillColor: MaterialStateProperty.resolveWith<Color>((_) => primary),
  ),
  switchTheme: SwitchThemeData(
    thumbColor: MaterialStateProperty.resolveWith<Color>((_) => primary),
    trackColor: MaterialStateProperty.resolveWith<Color>((_) => grey),
  ),
  snackBarTheme: SnackBarThemeData(
    backgroundColor: secondary,
    contentTextStyle: textTheme.headline6,
  ),
);
