import 'package:digital_3g_common/theme.dart';
import 'package:digital_3g_common/ui.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../api/auth_api.dart';
import '../models/user.dart';

class RegisterPage extends StatefulWidget {
  const RegisterPage({Key? key}) : super(key: key);

  @override
  _RegisterPageState createState() => _RegisterPageState();
}

class _RegisterPageState extends State<RegisterPage> {
  AuthApi? _authApi;

  final User _user = User(username: '');
  String _password = '';
  String _code = '';

  bool _showPassword = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Registrierung'),
      ),
      body: ListView(
        children: [
          PaddedCard(
              child: Form(
                  child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Text('Zugangscode vom Administrator'),
              TextFormField(
                decoration: const InputDecoration(labelText: 'Zugangscode'),
                onChanged: (String input) => setState(() => _code = input),
                validator: _validateNotEmpty,
                autovalidateMode: AutovalidateMode.onUserInteraction,
              ),
              const Divider(),
              const Text('Anmeldedaten'),
              TextFormField(
                decoration: const InputDecoration(labelText: 'Username'),
                onChanged: (String input) => setState(() => _user.username = input),
                validator: _validateNotEmpty,
                autovalidateMode: AutovalidateMode.onUserInteraction,
              ),
              TextFormField(
                decoration: InputDecoration(
                  labelText: 'Passwort',
                  suffix: IconButton(
                    onPressed: () => setState(() => _showPassword = !_showPassword),
                    icon: Icon(
                      Icons.remove_red_eye_rounded,
                      color: _showPassword ? secondary : darkGrey,
                    ),
                    constraints: const BoxConstraints(maxWidth: 24.0),
                    padding: EdgeInsets.zero,
                  ),
                ),
                onChanged: (String input) => setState(() => _password = input),
                obscureText: !_showPassword,
                validator: _validatePassword,
                autovalidateMode: AutovalidateMode.onUserInteraction,
              ),
              const Divider(),
              const Text('Persönliche Daten'),
              TextFormField(
                decoration: const InputDecoration(labelText: 'Vorname'),
                onChanged: (String input) => _user.name = input,
              ),
              TextFormField(
                decoration: const InputDecoration(labelText: 'Nachname'),
                onChanged: (String input) => _user.surname = input,
              ),
              const Divider(),
              Align(
                alignment: Alignment.centerRight,
                child: ElevatedButton(
                  onPressed: _user.username.isNotEmpty && _password.isNotEmpty ? _onSubmit : null,
                  child: const Text('Registrierung abschicken'),
                ),
              )
            ],
          )))
        ],
      ),
    );
  }

  @override
  void didChangeDependencies() {
    _authApi = Provider.of<AuthApi>(context, listen: false);
    super.didChangeDependencies();
  }

  void _onSubmit() async {
    final user = await _authApi!.register(user: _user, password: _password, code: _code);

    if (user != null && user.uuid != null) {
      await ScaffoldMessenger.of(context)
          .showSnackBar(const SnackBar(
              content: Text('Registrierung erfolgreich. Du wirst nun zurück zum Login geleitet')))
          .closed;
      Navigator.of(context).pop();
    } else {
      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
        content: Text(
            'Registrierung fehlgeschlagen. Starte die App neu und probiere es noch mal. Wenn es immer noch nicht klappt wende dich an deinen Administrator.'),
        duration: Duration(seconds: 5),
      ));
    }
  }

  String? _validateNotEmpty(String? input) =>
      input != null && input.isNotEmpty ? null : 'Pflichtfeld';

  String? _validatePassword(String? input) {
    final empty = _validateNotEmpty(input);
    if (empty != null) {
      return empty;
    }
    return input!.length > 4 ? null : 'Das Passwort muss mindestens 5 Zeichen enthalten';
  }
}
