import 'package:digital_3g_common/backend_switcher.dart';
import 'package:digital_3g_common/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_phoenix/flutter_phoenix.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart';
import 'package:logging/logging.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'config.dart';
import 'home_page.dart';
import 'settings_page.dart';
import 'verification_bloc.dart';

void main() async {
  if (debug) {
    Logger.root.level = Level.FINER;
    Logger.root.onRecord.listen((record) {
      // ignore: avoid_print
      print(
        '[${record.loggerName}] (${record.level.name}) ${record.time.toString().split('.')[0]}: ${record.message}',
      );
    });
  }

  runApp(Phoenix(child: const MyApp()));
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  Widget build(BuildContext context) {
    Intl.defaultLocale = 'de_DE';
    initializeDateFormatting('de_DE', null);
    return FutureBuilder(
      future: SharedPreferences.getInstance(),
      builder: (BuildContext context, AsyncSnapshot<SharedPreferences> data) {
        if (data.hasData) {
          final mode = data.data?.getString('digital_3g_backend_mode');
          final _bloc = BackendSwitcher(
            production: baseUrl,
            development: debugBaseUrl,
            mode: stringToMode(mode ?? 'production'),
          );
          return BlocProvider<BackendSwitcher>(
            create: (BuildContext context) => _bloc,
            child: BlocBuilder<BackendSwitcher, String>(
              bloc: _bloc,
              builder: (BuildContext context, String state) => BlocProvider<VerificationBloc>(
                create: (_) => VerificationBloc(
                  stringToMode(mode ?? 'production') == BackendMode.development
                      ? debugBaseUrl
                      : baseUrl,
                ),
                child: MaterialApp(
                  debugShowCheckedModeBanner: false,
                  title: '3-(di)G(i)',
                  theme: themeData,
                  initialRoute: '/',
                  routes: {
                    '/': (BuildContext context) => const HomePage(),
                    '/settings': (BuildContext context) => const SettingsPage(),
                  },
                ),
              ),
            ),
          );
        }
        return const SizedBox(width: 0.0, height: 0.0);
      },
    );
  }
}
